@@ -2,7 +2,7 @@
  * libvlc_media_player.h:  libvlc_media_player external API
  *****************************************************************************
  * Copyright (C) 1998-2015 VLC authors and VideoLAN
- * $Id: a20888140f60b8eca5d5e1d3157d30b5dd0b3ea4 $
+ * $Id: dbeafa29d1f4092ab265f2e45fab2bdd8edf5f2b $
  *
  * Authors: Clément Stenac <zorglub@videolan.org>
  *          Jean-Paul Saman <jpsaman@videolan.org>
@@ -1184,10 +1184,10 @@ LIBVLC_API void libvlc_video_set_aspect_ratio( libvlc_media_player_t *p_mi, cons
  */
 typedef struct libvlc_video_viewpoint_t
 {
-    float f_yaw;           /**< view point yaw in degrees */
-    float f_pitch;         /**< view point pitch in degrees */
-    float f_roll;          /**< view point roll in degrees */
-    float f_field_of_view; /**< field of view in degrees (default 80.0f) */
+    float f_yaw;           /**< view point yaw in degrees  ]-180;180] */
+    float f_pitch;         /**< view point pitch in degrees  ]-90;90] */
+    float f_roll;          /**< view point roll in degrees ]-180;180] */
+    float f_field_of_view; /**< field of view in degrees ]0;180[ (default 80.)*/
 } libvlc_video_viewpoint_t;
 
 /**
