@@ -718,6 +718,8 @@ static int Start(audio_output_t *aout, audio_sample_format_t *restrict fmt)
             fmt->i_format = VLC_CODEC_SPDIFL;
             fmt->i_bytes_per_frame = 4;
             fmt->i_frame_length = 1;
+            fmt->i_physical_channels = fmt->i_original_channels = AOUT_CHANS_2_0;
+            fmt->i_channels = 2;
             encoding = PA_ENCODING_AC3_IEC61937;
             ss.format = PA_SAMPLE_S16NE;
             break;
@@ -725,6 +727,8 @@ static int Start(audio_output_t *aout, audio_sample_format_t *restrict fmt)
             fmt->i_format = VLC_CODEC_SPDIFL;
             fmt->i_bytes_per_frame = 4;
             fmt->i_frame_length = 1;
+            fmt->i_physical_channels = fmt->i_original_channels = AOUT_CHANS_2_0;
+            fmt->i_channels = 2;
             encoding = PA_ENCODING_EAC3_IEC61937;
             ss.format = PA_SAMPLE_S16NE;
             break;
@@ -737,6 +741,8 @@ static int Start(audio_output_t *aout, audio_sample_format_t *restrict fmt)
             fmt->i_format = VLC_CODEC_SPDIFL;
             fmt->i_bytes_per_frame = 4;
             fmt->i_frame_length = 1;
+            fmt->i_physical_channels = fmt->i_original_channels = AOUT_CHANS_2_0;
+            fmt->i_channels = 2;
             encoding = PA_ENCODING_DTS_IEC61937;
             ss.format = PA_SAMPLE_S16NE;
             break;
