@@ -3,7 +3,7 @@
  *****************************************************************************
  * Copyright (C) 2009 Geoffroy Couprie
  * Copyright (C) 2009 Laurent Aimar
- * $Id: 668adbc919a5901b84bf6f18558562bf4a220915 $
+ * $Id: 31ca03185c0baec19332ce5fadc1d327d90e75b3 $
  *
  * Authors: Geoffroy Couprie <geal@videolan.org>
  *          Laurent Aimar <fenrir _AT_ videolan _DOT_ org>
@@ -40,6 +40,7 @@
 #define DXVA2API_USE_BITFIELDS
 #define COBJMACROS
 #include <libavcodec/dxva2.h>
+#include "../../video_chroma/d3d9_fmt.h"
 
 static int Open(vlc_va_t *, AVCodecContext *, enum PixelFormat,
                 const es_format_t *, picture_sys_t *p_sys);
@@ -134,11 +135,6 @@ struct vlc_va_sys_t
     struct dxva_context hw;
 };
 
-struct picture_sys_t
-{
-    LPDIRECT3DSURFACE9 surface;
-};
-
 static picture_t *DxAllocPicture(vlc_va_t *, const video_format_t *, unsigned index);
 
 
