@@ -2,7 +2,7 @@
  * libmpeg2.c: mpeg2 video decoder module making use of libmpeg2.
  *****************************************************************************
  * Copyright (C) 1999-2001 VLC authors and VideoLAN
- * $Id: f394f1b907601b5051326f70ab5e32bb887113f0 $
+ * $Id: 52972288c66faa961ad2acbb6bfcd209e3b8af6d $
  *
  * Authors: Gildas Bazin <gbazin@videolan.org>
  *          Christophe Massiot <massiot@via.ecp.fr>
@@ -99,7 +99,9 @@ struct decoder_sys_t
     uint32_t        i_cc_flags;
     mtime_t         i_cc_pts;
     mtime_t         i_cc_dts;
+#if MPEG2_RELEASE >= MPEG2_VERSION (0, 5, 0)
     cc_data_t       cc;
+#endif
     uint8_t        *p_gop_user_data;
     uint32_t        i_gop_user_data;
 };
@@ -112,6 +114,7 @@ static void CloseDecoder( vlc_object_t * );
 
 static int DecodeVideo( decoder_t *, block_t *);
 #if MPEG2_RELEASE >= MPEG2_VERSION (0, 5, 0)
+static void SendCc( decoder_t *p_dec );
 #endif
 
 static picture_t *GetNewPicture( decoder_t * );
@@ -432,21 +435,29 @@ static picture_t *DecodeBlock( decoder_t *p_dec, block_t **pp_block )
                              & PIC_MASK_CODING_TYPE) == PIC_FLAG_CODING_TYPE_B )
                     p_sys->i_cc_flags = BLOCK_FLAG_TYPE_B;
                 else p_sys->i_cc_flags = BLOCK_FLAG_TYPE_I;
+#if MPEG2_RELEASE >= MPEG2_VERSION (0, 5, 0)
                 bool b_top_field_first = p_sys->p_info->current_picture->flags
                                            & PIC_FLAG_TOP_FIELD_FIRST;
-
+#endif
                 if( p_sys->i_gop_user_data > 2 )
                 {
                     /* We now have picture info for any cached user_data out of the gop */
+#if MPEG2_RELEASE >= MPEG2_VERSION (0, 5, 0)
                     cc_ProbeAndExtract( &p_sys->cc, b_top_field_first,
                                 &p_sys->p_gop_user_data[0], p_sys->i_gop_user_data );
+#endif
                     p_sys->i_gop_user_data = 0;
                 }
 
                 /* Extract the CC from the user_data of the picture */
+#if MPEG2_RELEASE >= MPEG2_VERSION (0, 5, 0)
                 if( p_info->user_data_len > 2 )
                     cc_ProbeAndExtract( &p_sys->cc, b_top_field_first,
                                 &p_info->user_data[0], p_info->user_data_len );
+
+                if( p_sys->cc.i_data )
+                    SendCc( p_dec );
+#endif
             }
         }
         break;
@@ -594,34 +605,13 @@ static picture_t *DecodeBlock( decoder_t *p_dec, block_t **pp_block )
 
 static int DecodeVideo( decoder_t *p_dec, block_t *p_block)
 {
-    decoder_sys_t *p_sys = p_dec->p_sys;
-
     if( p_block == NULL ) /* No Drain */
         return VLCDEC_SUCCESS;
 
     block_t **pp_block = &p_block;
     picture_t *p_pic;
     while( ( p_pic = DecodeBlock( p_dec, pp_block ) ) != NULL )
-    {
-        block_t *p_cc = NULL;
-        bool *pb_present = NULL;
-#if MPEG2_RELEASE >= MPEG2_VERSION (0, 5, 0)
-        pb_present = p_sys->cc.pb_present;
-        if( p_sys->cc.i_data > 0 )
-        {
-            p_cc = block_Alloc( p_sys->cc.i_data);
-            if( p_cc )
-            {
-                memcpy( p_cc->p_buffer, p_sys->cc.p_data, p_sys->cc.i_data );
-                p_cc->i_dts =
-                p_cc->i_pts = p_sys->cc.b_reorder ? p_sys->i_cc_pts : p_sys->i_cc_dts;
-                p_cc->i_flags = ( p_sys->cc.b_reorder  ? p_sys->i_cc_flags : BLOCK_FLAG_TYPE_P ) & ( BLOCK_FLAG_TYPE_I|BLOCK_FLAG_TYPE_P|BLOCK_FLAG_TYPE_B);
-            }
-            cc_Flush( &p_sys->cc );
-        }
-#endif
-        decoder_QueueVideoWithCc( p_dec, p_pic, p_cc, pb_present );
-    }
+        decoder_QueueVideo( p_dec, p_pic );
     return VLCDEC_SUCCESS;
 }
 
@@ -633,6 +623,10 @@ static void CloseDecoder( vlc_object_t *p_this )
     decoder_t *p_dec = (decoder_t *)p_this;
     decoder_sys_t *p_sys = p_dec->p_sys;
 
+#if MPEG2_RELEASE >= MPEG2_VERSION (0, 5, 0)
+    cc_Flush( &p_sys->cc );
+#endif
+
     DpbClean( p_dec );
 
     free( p_sys->p_gop_user_data );
@@ -651,7 +645,9 @@ static void Reset( decoder_t *p_dec )
 {
     decoder_sys_t *p_sys = p_dec->p_sys;
 
+#if MPEG2_RELEASE >= MPEG2_VERSION (0, 5, 0)
     cc_Flush( &p_sys->cc );
+#endif
     mpeg2_reset( p_sys->p_mpeg2dec, 0 );
     DpbClean( p_dec );
 }
@@ -704,6 +700,32 @@ static picture_t *GetNewPicture( decoder_t *p_dec )
     return p_pic;
 }
 
+#if MPEG2_RELEASE >= MPEG2_VERSION (0, 5, 0)
+/*****************************************************************************
+ * SendCc: Sends the Closed Captions for the CC decoder.
+ *****************************************************************************/
+static void SendCc( decoder_t *p_dec )
+{
+    decoder_sys_t   *p_sys = p_dec->p_sys;
+    block_t         *p_cc = NULL;
+
+    if( p_sys->cc.i_data <= 0 )
+        return;
+
+    p_cc = block_Alloc( p_sys->cc.i_data);
+    if( p_cc )
+    {
+        memcpy( p_cc->p_buffer, p_sys->cc.p_data, p_sys->cc.i_data );
+        p_cc->i_dts =
+        p_cc->i_pts = p_sys->cc.b_reorder ? p_sys->i_cc_pts : p_sys->i_cc_dts;
+        p_cc->i_flags = ( p_sys->cc.b_reorder  ? p_sys->i_cc_flags : BLOCK_FLAG_TYPE_P ) & ( BLOCK_FLAG_TYPE_I|BLOCK_FLAG_TYPE_P|BLOCK_FLAG_TYPE_B);
+        decoder_QueueCc( p_dec, p_cc, p_sys->cc.pb_present, 0 );
+    }
+    cc_Flush( &p_sys->cc );
+    return;
+}
+#endif
+
 /*****************************************************************************
  * GetAR: Get aspect ratio
  *****************************************************************************/
