@@ -2,7 +2,7 @@
  * hotkeys.c: Hotkey handling for vlc
  *****************************************************************************
  * Copyright (C) 2005-2009 the VideoLAN team
- * $Id: 4e4f36897e2c174b32aac4f8322ed0d249f8f5f1 $
+ * $Id: 363eecda07b5d9b7fb1d5f6c1a9843236cd3ec05 $
  *
  * Authors: Sigmund Augdal Helberg <dnumgis@videolan.org>
  *          Jean-Paul Saman <jpsaman #_at_# m2x.nl>
@@ -737,7 +737,9 @@ static int PutAction( intf_thread_t *p_intf, input_thread_t *p_input,
                 var_FreeList( &list, &list2 );
             }
             break;
+
         case ACTIONID_SUBTITLE_TRACK:
+        case ACTIONID_SUBTITLE_REVERSE_TRACK:
             if( p_input )
             {
                 vlc_value_t val, list, list2;
@@ -768,10 +770,12 @@ static int PutAction( intf_thread_t *p_intf, input_thread_t *p_input,
                               "invalid current subtitle track, selecting 0" );
                     i = 0;
                 }
-                else if( i == i_count - 1 )
+                else if ((i == i_count - 1) && (i_action == ACTIONID_SUBTITLE_TRACK))
                     i = 0;
+                else if ((i == 0) && (i_action == ACTIONID_SUBTITLE_REVERSE_TRACK))
+                    i = i_count - 1;
                 else
-                    i++;
+                    i = (i_action == ACTIONID_SUBTITLE_TRACK) ? i+1 : i-1;
                 var_SetInteger( p_input, "spu-es", list.p_list->p_values[i].i_int );
                 var_SetInteger( p_input, "spu-choice", list.p_list->p_values[i].i_int );
                 DisplayMessage( p_vout, _("Subtitle track: %s"),
@@ -1189,6 +1193,15 @@ static int PutAction( intf_thread_t *p_intf, input_thread_t *p_input,
         case ACTIONID_UNZOOM:
             if( p_vout )
             {
+                bool b_autoscale = var_GetBool( p_vout, "autoscale" );
+                if( b_autoscale )
+                {
+                    DisplayMessage( p_vout, _("Original Size") );
+                    var_SetBool( p_vout, "autoscale", false );
+                    var_SetFloat( p_vout, "zoom", 1.f );
+                    break;
+                }
+
                 vlc_value_t val={0}, val_list, text_list;
                 var_Get( p_vout, "zoom", &val );
                 if( var_Change( p_vout, "zoom", VLC_VAR_GETCHOICES,
@@ -1419,8 +1432,7 @@ static void PlayBookmark( intf_thread_t *p_intf, int i_num )
         if( !strcmp( psz_bookmark, psz_uri ) )
         {
             free( psz_uri );
-            playlist_Control( p_playlist, PLAYLIST_VIEWPLAY, pl_Locked,
-                              NULL, p_item );
+            playlist_ViewPlay( p_playlist, NULL, p_item );
             break;
         }
         else
