@@ -2,7 +2,7 @@
  * ps.c: Program Stream demux module for VLC.
  *****************************************************************************
  * Copyright (C) 2004-2009 VLC authors and VideoLAN
- * $Id: c6d564f07b09b15d0557eb4fa3b3419221091e05 $
+ * $Id: 35cc91b7ba4049218ce38c0d23132d64e17c9768 $
  *
  * Authors: Laurent Aimar <fenrir@via.ecp.fr>
  *
@@ -138,7 +138,7 @@ static int OpenCommon( vlc_object_t *p_this, bool b_force )
     i_peek = vlc_stream_Peek( p_demux->s, &p_peek, 16 );
     if( i_peek < 16 )
     {
-        msg_Err( p_demux, "cannot peek" );
+        msg_Dbg( p_demux, "cannot peek" );
         return VLC_EGENERIC;
     }
 
