@@ -2,7 +2,7 @@
 * VLCSimplePrefsController.m: Simple Preferences for Mac OS X
 *****************************************************************************
 * Copyright (C) 2008-2014 VLC authors and VideoLAN
-* $Id: 2c4e54947e091ba3acfa53ede2176adb9d4f7356 $
+* $Id: 8b060a34e5b863487becd1c135dcbc1a7cccca0e $
 *
 * Authors: Felix Paul Kühne <fkuehne at videolan dot org>
 *
@@ -113,7 +113,7 @@ static const char *const ppsz_language_text[] =
 {
     N_("Auto"),
     "American English",
-    "ﻉﺮﺒﻳ",
+    "عربي",
     "বাংলা",
     "Português Brasileiro",
     "British English",
@@ -152,7 +152,7 @@ static const char *const ppsz_language_text[] =
     "ភាសាខ្មែរ",
     "नेपाली",
     "Occitan",
-    "ﻑﺍﺮﺳی",
+    "فارسی",
     "Polski",
     "Português",
     "ਪੰਜਾਬੀ",
