@@ -2,7 +2,7 @@
  * prefs.m: MacOS X module for vlc
  *****************************************************************************
  * Copyright (C) 2002-2015 VLC authors and VideoLAN
- * $Id: dbeed4798fe3a7aa389b637f27d7545a0194ddc4 $
+ * $Id: 449857fd33b72c0f2449c62f520889b30b3deccf $
  *
  * Authors: Jon Lech Johansen <jon-vl@nanocrew.net>
  *          Derk-Jan Hartman <hartman at videolan dot org>
@@ -232,7 +232,7 @@
 
 - (IBAction)resetPrefs:(id)sender
 {
-#warning implement me
+    [[[VLCMain sharedInstance] simplePreferences] resetPreferences:sender];
 }
 
 - (void)loadConfigTree
