@@ -2,7 +2,7 @@
  * prefs_widgets.m: Preferences controls
  *****************************************************************************
  * Copyright (C) 2002-2012 VLC authors and VideoLAN
- * $Id: 7ddd211696e3711acd7ae07bee8371bdf57b0440 $
+ * $Id: e7dfab789d7437b27e2e4f00aedfbc6f8c90b213 $
  *
  * Authors: Derk-Jan Hartman <hartman at videolan.org>
  *          Jérôme Decoodt <djc at videolan.org>
@@ -923,13 +923,10 @@ o_textfield = [[NSSecureTextField alloc] initWithFrame: s_rc];              \
         else
             self.viewType = CONFIG_ITEM_STRING;
 
-        o_textfieldTooltip = [[VLCStringUtility sharedInstance] wrapString: _NS((char *)p_item->psz_longtext) toWidth: PREFS_WRAP];
+        o_textfieldTooltip = [[VLCStringUtility sharedInstance] wrapString: _NS(p_item->psz_longtext) toWidth: PREFS_WRAP];
 
         /* add the label */
-        if (p_item->psz_text)
-            labelString = _NS((char *)p_item->psz_text);
-        else
-            labelString = @"";
+        labelString = _NS(p_item->psz_text);
         ADD_LABEL(self.label, mainFrame, 0, -3, labelString, o_textfieldTooltip)
         [self.label setAutoresizingMask:NSViewNotSizable ];
         [self addSubview: self.label];
@@ -1013,10 +1010,7 @@ o_textfield = [[NSSecureTextField alloc] initWithFrame: s_rc];              \
         o_textfieldTooltip = [[VLCStringUtility sharedInstance] wrapString: _NS(p_item->psz_longtext) toWidth: PREFS_WRAP];
 
         /* add the label */
-        if (p_item->psz_text)
-            labelString = _NS((char *)p_item->psz_text);
-        else
-            labelString = @"";
+        labelString = _NS(p_item->psz_text);
         ADD_LABEL(self.label, mainFrame, 0, -3, labelString, o_textfieldTooltip)
         [self.label setAutoresizingMask:NSViewNotSizable ];
         [self addSubview: self.label];
@@ -1111,16 +1105,13 @@ o_textfield = [[NSSecureTextField alloc] initWithFrame: s_rc];              \
     if ([super initWithFrame:mainFrame item:p_item] != nil) {
         self.viewType = CONFIG_ITEM_LOADFILE;
 
-        o_itemTooltip = [[VLCStringUtility sharedInstance] wrapString: _NS((char *)p_item->psz_longtext) toWidth: PREFS_WRAP];
+        o_itemTooltip = [[VLCStringUtility sharedInstance] wrapString: _NS(p_item->psz_longtext) toWidth: PREFS_WRAP];
 
         /* is it a directory */
         b_directory = ([self type] == CONFIG_ITEM_DIRECTORY) ? YES : NO;
 
         /* add the label */
-        if (p_item->psz_text)
-            labelString = _NS((char *)p_item->psz_text);
-        else
-            labelString = @"";
+        labelString = _NS(p_item->psz_text);
         ADD_LABEL(self.label, mainFrame, 0, 3, labelString, o_itemTooltip)
         [self.label setAutoresizingMask:NSViewNotSizable ];
         [self addSubview: self.label];
@@ -1210,13 +1201,10 @@ o_textfield = [[NSSecureTextField alloc] initWithFrame: s_rc];              \
     if ([super initWithFrame:mainFrame item:p_item] != nil) {
         self.viewType = CONFIG_ITEM_MODULE;
 
-        o_popupTooltip = [[VLCStringUtility sharedInstance] wrapString: _NS((char *)p_item->psz_longtext) toWidth: PREFS_WRAP];
+        o_popupTooltip = [[VLCStringUtility sharedInstance] wrapString: _NS(p_item->psz_longtext) toWidth: PREFS_WRAP];
 
         /* add the label */
-        if (p_item->psz_text)
-            labelString = _NS((char *)p_item->psz_text);
-        else
-            labelString = @"";
+        labelString = _NS(p_item->psz_text);
 
         ADD_LABEL(self.label, mainFrame, 0, -1, labelString, o_popupTooltip)
         [self.label setAutoresizingMask:NSViewNotSizable ];
@@ -1345,13 +1333,10 @@ o_textfield = [[NSSecureTextField alloc] initWithFrame: s_rc];              \
     if ([super initWithFrame:mainFrame item:p_item] != nil) {
         self.viewType = CONFIG_ITEM_INTEGER;
 
-        toolTip = [[VLCStringUtility sharedInstance] wrapString: _NS((char *)p_item->psz_longtext) toWidth: PREFS_WRAP];
+        toolTip = [[VLCStringUtility sharedInstance] wrapString: _NS(p_item->psz_longtext) toWidth: PREFS_WRAP];
 
         /* add the label */
-        if (p_item->psz_text)
-            labelString = _NS((char *)p_item->psz_text);
-        else
-            labelString = @"";
+        labelString = _NS((char *)p_item->psz_text);
         ADD_LABEL(self.label, mainFrame, 0, -3, labelString, toolTip)
         [self.label setAutoresizingMask:NSViewNotSizable ];
         [self addSubview: self.label];
@@ -1437,13 +1422,10 @@ o_textfield = [[NSSecureTextField alloc] initWithFrame: s_rc];              \
     if ([super initWithFrame:mainFrame item:p_item] != nil) {
         self.viewType = CONFIG_ITEM_STRING_LIST;
 
-        o_textfieldTooltip = [[VLCStringUtility sharedInstance] wrapString: _NS((char *)p_item->psz_longtext) toWidth: PREFS_WRAP];
+        o_textfieldTooltip = [[VLCStringUtility sharedInstance] wrapString: _NS(p_item->psz_longtext) toWidth: PREFS_WRAP];
 
         /* add the label */
-        if (p_item->psz_text)
-            labelString = _NS((char *)p_item->psz_text);
-        else
-            labelString = @"";
+        labelString = _NS(p_item->psz_text);
         ADD_LABEL(self.label, mainFrame, 0, -3, labelString, o_textfieldTooltip)
         [self.label setAutoresizingMask:NSViewNotSizable ];
         [self addSubview: self.label];
@@ -1530,13 +1512,10 @@ o_textfield = [[NSSecureTextField alloc] initWithFrame: s_rc];              \
     if ([super initWithFrame: mainFrame item:p_item] != nil) {
         self.viewType = CONFIG_ITEM_RANGED_INTEGER;
 
-        toolTip = [[VLCStringUtility sharedInstance] wrapString: _NS((char *)p_item->psz_longtext) toWidth: PREFS_WRAP];
+        toolTip = [[VLCStringUtility sharedInstance] wrapString: _NS(p_item->psz_longtext) toWidth: PREFS_WRAP];
 
         /* add the label */
-        if (p_item->psz_text)
-            labelString = _NS((char *)p_item->psz_text);
-        else
-            labelString = @"";
+        labelString = _NS(p_item->psz_text);
         ADD_LABEL(self.label, mainFrame, 0, -3, labelString, toolTip)
         [self.label setAutoresizingMask:NSViewNotSizable ];
         [self addSubview: self.label];
@@ -1643,13 +1622,10 @@ o_textfield = [[NSSecureTextField alloc] initWithFrame: s_rc];              \
     if ([super initWithFrame:mainFrame item:p_item] != nil) {
         self.viewType = CONFIG_ITEM_INTEGER;
 
-        toolTip = [[VLCStringUtility sharedInstance] wrapString: _NS((char *)p_item->psz_longtext) toWidth: PREFS_WRAP];
+        toolTip = [[VLCStringUtility sharedInstance] wrapString: _NS(p_item->psz_longtext) toWidth: PREFS_WRAP];
 
         /* add the label */
-        if (p_item->psz_text)
-            labelString = _NS((char *)p_item->psz_text);
-        else
-            labelString = @"";
+        labelString = _NS(p_item->psz_text);
         ADD_LABEL(self.label, mainFrame, 0, -2, labelString, toolTip)
         [self.label setAutoresizingMask:NSViewNotSizable ];
         [self addSubview: self.label];
@@ -1737,13 +1713,10 @@ o_textfield = [[NSSecureTextField alloc] initWithFrame: s_rc];              \
     if ([super initWithFrame:mainFrame item:p_item] != nil) {
         self.viewType = CONFIG_ITEM_RANGED_INTEGER;
 
-        toolTip = [[VLCStringUtility sharedInstance] wrapString: _NS((char *)p_item->psz_longtext) toWidth: PREFS_WRAP];
+        toolTip = [[VLCStringUtility sharedInstance] wrapString: _NS(p_item->psz_longtext) toWidth: PREFS_WRAP];
 
         /* add the label */
-        if (p_item->psz_text)
-            labelString = _NS((char *)p_item->psz_text);
-        else
-            labelString = @"";
+        labelString = _NS(p_item->psz_text);
         ADD_LABEL(self.label, mainFrame, 0, -3, labelString, toolTip)
         [self.label setAutoresizingMask:NSViewNotSizable ];
         [self addSubview: self.label];
@@ -1851,12 +1824,9 @@ o_textfield = [[NSSecureTextField alloc] initWithFrame: s_rc];              \
     if (self != nil) {
         self.viewType = CONFIG_ITEM_BOOL;
 
-        if (p_item->psz_text)
-            labelString = _NS((char *)p_item->psz_text);
-        else
-            labelString = @"";
+        labelString = _NS(p_item->psz_text);
 
-        toolTip = [[VLCStringUtility sharedInstance] wrapString: _NS((char *)p_item->psz_longtext) toWidth: PREFS_WRAP];
+        toolTip = [[VLCStringUtility sharedInstance] wrapString: _NS(p_item->psz_longtext) toWidth: PREFS_WRAP];
 
         /* add the checkbox */
         ADD_CHECKBOX(o_checkbox, mainFrame, 0,
@@ -1899,13 +1869,10 @@ o_textfield = [[NSSecureTextField alloc] initWithFrame: s_rc];              \
     if ([super initWithFrame:mainFrame item:p_item] != nil) {
         self.viewType = CONFIG_ITEM_KEY;
 
-        toolTip = [[VLCStringUtility sharedInstance] wrapString: _NS((char *)p_item->psz_longtext) toWidth: PREFS_WRAP];
+        toolTip = [[VLCStringUtility sharedInstance] wrapString: _NS(p_item->psz_longtext) toWidth: PREFS_WRAP];
 
         /* add the label */
-        if (p_item->psz_text)
-            labelString = _NS((char *)p_item->psz_text);
-        else
-            labelString = @"";
+        labelString = _NS(p_item->psz_text);
         ADD_LABEL(self.label, mainFrame, 0, -1, labelString, toolTip)
         [self.label setAutoresizingMask:NSViewNotSizable ];
         [self addSubview: self.label];
@@ -2116,20 +2083,17 @@ o_moduleenabled = [NSNumber numberWithBool:NO];\
     if ([super initWithFrame:mainFrame item:p_item] != nil) {
         self.viewType = CONFIG_ITEM_MODULE_LIST;
 
-        toolTip = [[VLCStringUtility sharedInstance] wrapString: _NS((char *)p_item->psz_longtext) toWidth: PREFS_WRAP];
+        toolTip = [[VLCStringUtility sharedInstance] wrapString: _NS(p_item->psz_longtext) toWidth: PREFS_WRAP];
 
         /* add the label */
-        if (p_item->psz_text)
-            labelString = _NS((char *)p_item->psz_text);
-        else
-            labelString = @"";
+        labelString = _NS((char *)p_item->psz_text);
         ADD_LABEL(self.label, mainFrame, 0, -3, labelString, toolTip)
         [self.label setAutoresizingMask:NSViewNotSizable ];
         [self addSubview: self.label];
 
         /* build the textfield */
         if (p_item->value.psz)
-            o_textfieldString = _NS((char *)p_item->value.psz);
+            o_textfieldString = _NS(p_item->value.psz);
         else
             o_textfieldString = @"";
         ADD_TEXTFIELD(o_textfield, mainFrame, [self.label frame].size.width + 2,
@@ -2304,11 +2268,8 @@ objectValueForTableColumn:(NSTableColumn *)aTableColumn row:(NSInteger)rowIndex
 
     if ([super initWithFrame:mainFrame item:p_item] != nil) {
         /* add the label */
-        if (p_item->psz_text)
-            labelString = _NS((char *)p_item->psz_text);
-        else
-            labelString = @"";
-        
+        labelString = _NS(p_item->psz_text);
+
         NSDictionary *boldAttributes = [NSDictionary dictionaryWithObjectsAndKeys:
                                         [NSFont boldSystemFontOfSize:[NSFont systemFontSize]],
                                         NSFontAttributeName,
@@ -2318,7 +2279,7 @@ objectValueForTableColumn:(NSTableColumn *)aTableColumn row:(NSInteger)rowIndex
         ADD_LABEL(self.label, mainFrame, 1, 0, @"", @"")
         [self.label setAttributedStringValue: o_bold_string];
         [self.label sizeToFit];
-        
+
         [self.label setAutoresizingMask:NSViewNotSizable];
         [self addSubview: self.label];
     }
@@ -2326,6 +2287,3 @@ objectValueForTableColumn:(NSTableColumn *)aTableColumn row:(NSInteger)rowIndex
 }
 
 @end
-
-//#undef CONFIG_ITEM_LIST_STRING
-//#undef CONFIG_ITEM_RANGED_INTEGER
