@@ -2,7 +2,7 @@
  * extended_panels.cpp : Extended controls panels
  ****************************************************************************
  * Copyright (C) 2006-2013 the VideoLAN team
- * $Id: 25107b2cc52fce36200fdb2b034a79cd0962adec $
+ * $Id: d8c0f514ac332f41885d16a8ae16ea6085096910 $
  *
  * Authors: Clément Stenac <zorglub@videolan.org>
  *          Antoine Cellerier <dionoea .t videolan d@t org>
@@ -274,7 +274,7 @@ static void ChangeAFiltersString( struct intf_thread_t *p_intf, const char *psz_
         return;
     }
 
-    QString result = ChangeFiltersString( p_intf, "audio-filteR", psz_name, b_add );
+    QString result = ChangeFiltersString( p_intf, "audio-filter", psz_name, b_add );
     config_PutPsz( p_intf, "audio-filter", qtu( result ) );
 }
 
@@ -620,33 +620,6 @@ void ExtVideo::updateFilterOptions()
     setFilterOption( p_intf, qtu( module ), qtu( option ), i_int, f_float, val);
 }
 
-int ExtVideo::getPostprocessing( struct intf_thread_t *p_intf)
-{
-    char *psz_config = config_GetPsz(p_intf, "video-filter");
-    int i_q = -1;
-    if (psz_config) {
-        if (strstr(psz_config, "postproc"))
-            i_q = config_GetInt(p_intf, "postproc-q");
-        free(psz_config);
-    }
-    return i_q;
-}
-
-void ExtVideo::setPostprocessing( struct intf_thread_t *p_intf, int q)
-{
-    const char *psz_name = "postproc";
-
-    if( q == -1 )
-    {
-        ChangeVFiltersString( p_intf, psz_name, false );
-    }
-    else
-    {
-        ChangeVFiltersString( p_intf, psz_name, false );
-        setFilterOption( p_intf, "postproc", "postproc-q", q, -1, QString() );
-    }
-}
-
 /**********************************************************************
  * v4l2 controls
  **********************************************************************/
@@ -1005,11 +978,6 @@ void AudioFilterControlWidget::build()
     free( psz_af );
 }
 
-AudioFilterControlWidget::~AudioFilterControlWidget()
-{
-
-}
-
 void AudioFilterControlWidget::enable( bool b_enable ) const
 {
     ChangeAFiltersString( p_intf, qtu(name), b_enable );
