@@ -2,7 +2,7 @@
  * selector.cpp : Playlist source selector
  ****************************************************************************
  * Copyright (C) 2006-2009 the VideoLAN team
- * $Id: c02a024b24e5af78b2295ad2740eb4d476041a3e $
+ * $Id: 1d41f7f6afd39f26f66467eb8b14762bd249f994 $
  *
  * Authors: Clément Stenac <zorglub@videolan.org>
  *          Jean-Baptiste Kempf
@@ -390,7 +390,7 @@ void PLSelector::setSource( QTreeWidgetItem *item )
     {
         /* Find the right item for the SD */
         /* FIXME: searching by name - what could possibly go wrong? */
-        pl_item = playlist_ChildSearchName( THEPL->p_root,
+        pl_item = playlist_ChildSearchName( &(THEPL->root),
             vlc_gettext(qtu(item->data(0, LONGNAME_ROLE).toString())) );
 
         /* Podcasts */
