@@ -2,7 +2,7 @@
  * input_manager.cpp : Manage an input and interact with its GUI elements
  ****************************************************************************
  * Copyright (C) 2006-2008 the VideoLAN team
- * $Id: 55e05531a6e9c3254afc63faf6e67fd42f3f60a7 $
+ * $Id: d5285cf6a082c54db6956817a55b079f7af83d9a $
  *
  * Authors: Clément Stenac <zorglub@videolan.org>
  *          Ilkka Ollakka  <ileoo@videolan.org>
@@ -250,9 +250,6 @@ void InputManager::customEvent( QEvent *event )
     case IMEvent::ItemStateChanged:
         UpdateStatus();
         break;
-    case IMEvent::NameChanged:
-        UpdateName();
-        break;
     case IMEvent::MetaChanged:
         UpdateMeta();
         UpdateName(); /* Needed for NowPlaying */
@@ -377,9 +374,6 @@ static int InputEvent( vlc_object_t *, const char *,
     case INPUT_EVENT_ITEM_INFO: /* Codec Info */
         event = new IMEvent( IMEvent::InfoChanged );
         break;
-    case INPUT_EVENT_ITEM_NAME:
-        event = new IMEvent( IMEvent::NameChanged );
-        break;
 
     case INPUT_EVENT_AUDIO_DELAY:
     case INPUT_EVENT_SUBTITLE_DELAY:
