@@ -2,7 +2,7 @@
  * upnp.cpp :  UPnP discovery module (libupnp)
  *****************************************************************************
  * Copyright (C) 2004-2016 VLC authors and VideoLAN
- * $Id: 93aa2997d30ff2030305e606b4ae605f34cfc494 $
+ * $Id: ba61a75c021ca8b6722d5f2723c0225917bf966f $
  *
  * Authors: Rémi Denis-Courmont <rem # videolan.org> (original plugin)
  *          Christian Henz <henz # c-lab.de>
@@ -344,7 +344,7 @@ bool MediaServerList::addServer( MediaServerDesc* desc )
         input_item_SetArtworkURL( p_input_item, desc->iconUrl.c_str() );
     desc->inputItem = p_input_item;
     input_item_SetDescription( p_input_item, desc->UDN.c_str() );
-    services_discovery_AddItem( m_sd, p_input_item, NULL );
+    services_discovery_AddItem( m_sd, p_input_item );
     m_list.push_back( desc );
 
     return true;
