@@ -2,7 +2,7 @@
  * raop.c: Remote Audio Output Protocol streaming support
  *****************************************************************************
  * Copyright (C) 2008 VLC authors and VideoLAN
- * $Id: 48b7cd18f6d8be2e19425719b2deeef5dee9afe8 $
+ * $Id: 0903fc9ac09f1be55ed1078fe734a5814975c34f $
  *
  * Author: Michael Hanselmann
  *
@@ -722,6 +722,10 @@ static void WriteAuxHeaders( struct vlc_memstream *restrict stream,
                              vlc_dictionary_t *p_req_headers )
 {
     char **ppsz_keys = vlc_dictionary_all_keys( p_req_headers );
+
+    if( unlikely( !ppsz_keys ) )
+        return;
+
     for( size_t i = 0; ppsz_keys[i] != NULL; i++ )
     {
         char *name = ppsz_keys[i];
