@@ -1511,7 +1511,7 @@ int rtp_add_sink( sout_stream_id_sys_t *id, int fd, bool rtcp_mux, uint16_t *seq
         msg_Err( id->p_stream, "RTCP failed!" );
 
     vlc_mutex_lock( &id->lock_sink );
-    INSERT_ELEM( id->sinkv, id->sinkc, id->sinkc, sink );
+    TAB_APPEND(id->sinkc, id->sinkv, sink);
     if( seq != NULL )
         *seq = id->i_seq_sent_next;
     vlc_mutex_unlock( &id->lock_sink );
@@ -1529,7 +1529,7 @@ void rtp_del_sink( sout_stream_id_sys_t *id, int fd )
         if (id->sinkv[i].rtp_fd == fd)
         {
             sink = id->sinkv[i];
-            REMOVE_ELEM( id->sinkv, id->sinkc, i );
+            TAB_ERASE(id->sinkc, id->sinkv, i);
             break;
         }
     }
