@@ -2,7 +2,7 @@
  * video.c: transcoding stream output module (video)
  *****************************************************************************
  * Copyright (C) 2003-2009 VLC authors and VideoLAN
- * $Id: 47491f1cdacb2dc67bc6f991f9373c4660f2e7f7 $
+ * $Id: 250ae143eee875a79522d1485df2147279ab68f9 $
  *
  * Authors: Laurent Aimar <fenrir@via.ecp.fr>
  *          Gildas Bazin <gbazin@videolan.org>
@@ -148,15 +148,10 @@ static void* EncoderThread( void *obj )
     return NULL;
 }
 
-static int decoder_queue_video( decoder_t *p_dec, picture_t *p_pic,
-                                block_t *p_cc, bool p_cc_present[4] )
+static int decoder_queue_video( decoder_t *p_dec, picture_t *p_pic )
 {
     sout_stream_id_sys_t *id = p_dec->p_queue_ctx;
 
-    (void) p_cc_present;
-    if( unlikely( p_cc != NULL ) )
-        block_Release( p_cc );
-
     vlc_mutex_lock(&id->fifo.lock);
     *id->fifo.pic.last = p_pic;
     id->fifo.pic.last = &p_pic->p_next;
