@@ -2,7 +2,7 @@
  * common.c: Windows video output common code
  *****************************************************************************
  * Copyright (C) 2001-2009 VLC authors and VideoLAN
- * $Id: 8ef0aef529cd8b53853c0e555c3acdcf3b219bca $
+ * $Id: 328139bee41d27bf0ef204eaafd5673b73a50eac $
  *
  * Authors: Gildas Bazin <gbazin@videolan.org>
  *          Martell Malone <martellmalone@gmail.com>
@@ -691,7 +691,7 @@ int CommonControl(vout_display_t *vd, int query, va_list args)
             UpdateRects(vd, cfg, source, true);
         } else {
             cfg    = va_arg(args, const vout_display_cfg_t *);
-            UpdateRects(vd, cfg, NULL, false);
+            UpdateRects(vd, cfg, NULL, true);
         }
         return VLC_SUCCESS;
     }
