@@ -2,7 +2,7 @@
  * access.c
  *****************************************************************************
  * Copyright (C) 1999-2008 VLC authors and VideoLAN
- * $Id: 2b1a9cc592ab65f5d1f5956bededc5c9ed819273 $
+ * $Id: 7fca5cff17d6ce76de15919f9ea5de71f5c2afcf $
  *
  * Author: Laurent Aimar <fenrir _AT_ videolan _DOT_ org>
  *
@@ -617,6 +617,8 @@ static void fsdir_attach_slaves(struct access_fsdir *p_fsdir)
              * added in the parent node */
             if (p_fsdir_slave->p_node != NULL)
             {
+                input_item_node_RemoveNode(p_fsdir->p_node,
+                                           p_fsdir_slave->p_node);
                 input_item_node_Delete(p_fsdir_slave->p_node);
                 p_fsdir_slave->p_node = NULL;
             }
@@ -687,8 +689,7 @@ int access_fsdir_additem(struct access_fsdir *p_fsdir,
             return VLC_ENOMEM;
         }
 
-        INSERT_ELEM(p_fsdir->pp_slaves, p_fsdir->i_slaves,
-                    p_fsdir->i_slaves, p_fsdir_slave);
+        TAB_APPEND(p_fsdir->i_slaves, p_fsdir->pp_slaves, p_fsdir_slave);
     }
 
     if (fsdir_is_ignored(p_fsdir, psz_filename))
