@@ -2,7 +2,7 @@
  * es_format.c : es_format_t helpers.
  *****************************************************************************
  * Copyright (C) 2008 VLC authors and VideoLAN
- * $Id: ab27a32ae81244fc3d75fd0dac967b7c9f8c0616 $
+ * $Id: a436599058abc73f554ab419e8aa30ff70b1648b $
  *
  * Author: Laurent Aimar <fenrir@videolan.org>
  *
@@ -435,28 +435,21 @@ void video_format_Print( vlc_object_t *p_this,
 void es_format_Init( es_format_t *fmt,
                      int i_cat, vlc_fourcc_t i_codec )
 {
+    memset(fmt, 0, sizeof (*fmt));
     fmt->i_cat                  = i_cat;
     fmt->i_codec                = i_codec;
-    fmt->i_original_fourcc      = 0;
     fmt->i_profile              = -1;
     fmt->i_level                = -1;
     fmt->i_id                   = -1;
-    fmt->i_group                = 0;
     fmt->i_priority             = ES_PRIORITY_SELECTABLE_MIN;
     fmt->psz_language           = NULL;
     fmt->psz_description        = NULL;
-
-    fmt->i_extra_languages      = 0;
     fmt->p_extra_languages      = NULL;
 
-    memset( &fmt->audio, 0, sizeof(audio_format_t) );
-    memset( &fmt->audio_replay_gain, 0, sizeof(audio_replay_gain_t) );
-    video_format_Init( &fmt->video, 0 );
-    memset( &fmt->subs, 0, sizeof(subs_format_t) );
+    if (fmt->i_cat == VIDEO_ES)
+        video_format_Init(&fmt->video, 0);
 
     fmt->b_packetized           = true;
-    fmt->i_bitrate              = 0;
-    fmt->i_extra                = 0;
     fmt->p_extra                = NULL;
 }
 
@@ -499,22 +492,24 @@ int es_format_Copy(es_format_t *restrict dst, const es_format_t *src)
         }
     }
 
-    if (src->subs.psz_encoding != NULL)
-    {
-        dst->subs.psz_encoding = strdup(src->subs.psz_encoding);
-        if (unlikely(dst->subs.psz_encoding == NULL))
-            ret = VLC_ENOMEM;
-    }
-    if (src->subs.p_style != NULL)
-    {
-        dst->subs.p_style = text_style_Duplicate(src->subs.p_style);
-        if (unlikely(dst->subs.p_style == NULL))
-            ret = VLC_ENOMEM;
-    }
+    if (src->i_cat == VIDEO_ES)
+        ret = video_format_Copy( &dst->video, &src->video );
 
-    int err = video_format_Copy( &dst->video, &src->video );
-    if ( err != VLC_SUCCESS )
-        return err;
+    if (src->i_cat == SPU_ES)
+    {
+        if (src->subs.psz_encoding != NULL)
+        {
+            dst->subs.psz_encoding = strdup(src->subs.psz_encoding);
+            if (unlikely(dst->subs.psz_encoding == NULL))
+                ret = VLC_ENOMEM;
+        }
+        if (src->subs.p_style != NULL)
+        {
+            dst->subs.p_style = text_style_Duplicate(src->subs.p_style);
+            if (unlikely(dst->subs.p_style == NULL))
+                ret = VLC_ENOMEM;
+        }
+    }
 
     if (src->i_extra_languages > 0)
     {
@@ -548,11 +543,15 @@ void es_format_Clean(es_format_t *fmt)
     assert(fmt->i_extra == 0 || fmt->p_extra != NULL);
     free(fmt->p_extra);
 
-    video_format_Clean( &fmt->video );
-    free(fmt->subs.psz_encoding);
+    if (fmt->i_cat == VIDEO_ES)
+        video_format_Clean( &fmt->video );
+    if (fmt->i_cat == SPU_ES)
+    {
+        free(fmt->subs.psz_encoding);
 
-    if (fmt->subs.p_style != NULL)
-        text_style_Delete(fmt->subs.p_style);
+        if (fmt->subs.p_style != NULL)
+            text_style_Delete(fmt->subs.p_style);
+    }
 
     for (unsigned i = 0; i < fmt->i_extra_languages; i++)
     {
