@@ -2,7 +2,7 @@
  * image.c : wrapper for image reading/writing facilities
  *****************************************************************************
  * Copyright (C) 2004-2007 VLC authors and VideoLAN
- * $Id: 313d21386e3cfcb23415eeefd71f17ca6474c1fa $
+ * $Id: 9b4631ecaa442bed307b73991c1ed60c6903db29 $
  *
  * Author: Gildas Bazin <gbazin@videolan.org>
  *
@@ -121,13 +121,8 @@ void image_HandlerDelete( image_handler_t *p_image )
  *
  */
 
-static int ImageQueueVideo( decoder_t *p_dec, picture_t *p_pic,
-                            block_t *p_cc, bool p_cc_present[4] )
+static int ImageQueueVideo( decoder_t *p_dec, picture_t *p_pic )
 {
-    (void) p_cc_present;
-    if( unlikely( p_cc != NULL ) )
-        block_Release( p_cc );
-
     image_handler_t *p_image = p_dec->p_queue_ctx;
     picture_fifo_Push( p_image->outfifo, p_pic );
     return 0;
@@ -256,9 +251,15 @@ static picture_t *ImageRead( image_handler_t *p_image, block_t *p_block,
         }
 
         p_pic = p_image->p_filter->pf_video_filter( p_image->p_filter, p_pic );
-        *p_fmt_out = p_image->p_filter->fmt_out.video;
+
+        video_format_Clean( p_fmt_out );
+        video_format_Copy( p_fmt_out, &p_image->p_filter->fmt_out.video );
+    }
+    else
+    {
+        video_format_Clean( p_fmt_out );
+        video_format_Copy( p_fmt_out, &p_image->p_dec->fmt_out.video );
     }
-    else *p_fmt_out = p_image->p_dec->fmt_out.video;
 
     return p_pic;
 }
