@@ -3,7 +3,7 @@
  *****************************************************************************
  * Copyright (C) 2006 VLC authors and VideoLAN
  * Copyright (C) 2008-2009 Rémi Denis-Courmont
- * $Id: eb45145b315dba526ad7f4a58ef9060482fa9c58 $
+ * $Id: ec68de3fc2d8c51e6f23dbbcd531618c1a0de4c4 $
  *
  * Authors: Antoine Cellerier <dionoea at videolan dot org>
  *          Daniel Stranger <vlc at schmaller dot de>
@@ -47,6 +47,7 @@
 
 #include <vlc_strings.h>
 #include <vlc_charset.h>
+#include <vlc_arrays.h>
 #include <libvlc.h>
 #include <errno.h>
 
@@ -254,7 +255,7 @@ void vlc_xml_decode( char *psz_value )
                 const struct xml_entity_s *ent;
 
                 ent = bsearch (psz_value + 1, xml_entities,
-                               sizeof (xml_entities) / sizeof (*ent),
+                               ARRAY_SIZE (xml_entities),
                                sizeof (*ent), cmp_entity);
                 if (ent != NULL)
                 {
