@@ -6,7 +6,7 @@
  * thread, and destroy a previously oppened video output thread.
  *****************************************************************************
  * Copyright (C) 2000-2007 VLC authors and VideoLAN
- * $Id: e6a36f982841a024d512089c111695df86bc3401 $
+ * $Id: 730b902b24f29577574b674d0da7d53390c6d777 $
  *
  * Authors: Vincent Seguin <seguin@via.ecp.fr>
  *          Gildas Bazin <gbazin@videolan.org>
@@ -714,7 +714,7 @@ static void ThreadChangeFilters(vout_thread_t *vout,
     {
         vout_filter_t *e = malloc(sizeof(*e));
 
-        if (e)
+        if (likely(e))
         {
             free(config_ChainCreate(&e->name, &e->cfg, "deinterlace"));
             vlc_array_append(&array_static, e);
@@ -730,7 +730,7 @@ static void ThreadChangeFilters(vout_thread_t *vout,
         if (name && *name) {
             vout_filter_t *e = malloc(sizeof(*e));
 
-            if (e) {
+            if (likely(e)) {
                 e->name = name;
                 e->cfg  = cfg;
                 if (!strcmp(e->name, "postproc"))
